# -*- coding: utf-8 -*-

themes = {'Bootstrap': 'bootstrap.min.css',
          'Readable': 'readable.min.css',
          'Journal': 'journal.min.css',
          'Flat UI': 'flat-ui.min.css'}
